@@ -159,18 +159,16 @@ class Schema:
                     )
                 elif (
                     isinstance(field, ManyRelatedField)
-                    and field.child_relation.queryset.model in cls.objecttype_registry
+                    and field.parent.__class__.Meta.model in cls.objecttype_registry
                 ):
 
                     def field_resolver(source, info, **kwargs):
                         return getattr(source, info.field_name).all()
 
-                    if field.child_relation.queryset.model in cls.objecttype_registry:
+                    if field.parent.__class__.Meta.model in cls.objecttype_registry:
                         obj_type.fields[field_name] = GraphQLField(
                             GraphQLList(
-                                cls.objecttype_registry[
-                                    field.child_relation.queryset.model
-                                ]
+                                cls.objecttype_registry[field.parent.__class__.Meta.model]
                             ),
                             resolve=field_resolver,
                         )
@@ -387,9 +385,9 @@ class ModelSerializerType:
         field: str = "",
         list_field: str = None,
         queryset: QuerySet = None,
-        create_mutation: bool = True,
-        update_mutation: bool = True,
-        delete_mutation: bool = True,
+        create_mutation: bool = False,
+        update_mutation: bool = False,
+        delete_mutation: bool = False,
     ):
         self.name = name or self.__class__.__name__
         self.singular_lookup_fields = singular_lookup_fields
